@@ -493,6 +493,22 @@ class BoxSession(object):
             query_string[key] = value
         return self.__request("GET","search",querystring=query_string)
 
+    def get_user_info(self):
+        """Gets the user's information
+
+        Args:
+
+        Returns:
+            dict. Response from box
+
+        Raises:
+            BoxError: An error response is returned from Box (status_code >= 400).
+
+            BoxHttpResponseError: Response from Box is malformed.
+
+            requests.exceptions.*: Any connection related problem.
+        """
+        return self.__request("GET","users/me")
 
 show_debug_messages = False
 
